scangen
=======

scangen is a scanner generator that uses Jinja2 templates.

Prerequisites
-------------

scangen requires [libcrnd](https://github.com/lggruspe/rnd).

Installation
------------

`pip install scangen`.

Usage
-----

Go to `examples`, run `make` and see the output files in `examples/build`.
On Linux, you might have to do add `/usr/local/lib` to `LD_LIBRARY_PATH` before running `scangen`.

License
-------

MIT.
